/***************************************
    This is part of frox: A simple transparent FTP proxy
    Copyright (C) 2000 James Hollingshead

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    systwrap.h -- Wrappers for various system calls, mainly to deal with 
                  EINTR errors.
					
***************************************/


#ifndef SYSTWRAP_H
#define SYSTWRAP_H    /*+ To stop multiple inclusions. +*/

#include <errno.h>
#include "common.h"

static inline ssize_t iread(int fd, void *buf, size_t count)
{
	int i;
	do{
		i=read(fd, buf, count);
	}while(i==-1 && errno==EINTR);
	return(i);
}

static inline ssize_t iwrite(int fd, void *buf, size_t count)
{
	int i;
	do{
		i=write(fd, buf, count);
	}while(i==-1 && errno==EINTR);
	return(i);
}

static inline int iselect(int n, fd_set *r, fd_set *w, fd_set *e, struct timeval *t)
{
	fd_set r1, w1, e1;
	struct timeval t1;
	int i;
	if(r!=NULL) r1=*r;
	if(w!=NULL) w1=*w;
	if(e!=NULL) e1=*e;
	if(t!=NULL) t1=*t;
	do{
		if(r!=NULL) *r=r1;
		if(w!=NULL) *w=w1;
		if(e!=NULL) *e=e1;
		if(t!=NULL) *t=t1;
		i=select(n, r, w, e, t);
	}while(i==-1 && errno==EINTR);
	return(i);
}

#endif /* SYSTWRAP_H */
